"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.mqttHandler = exports.initDeviceService = exports.deviceFeatures = void 0;
const motionDevice_1 = require("./motionDevice");
const leakDevice_1 = require("./leakDevice");
const valveDevice_1 = require("./valveDevice");
const thermoHydroDevice_1 = require("./thermoHydroDevice");
const contactDevice_1 = require("./contactDevice");
const switchDevice_1 = require("./switchDevice");
const outletDevice_1 = require("./outletDevice");
const statelessSwitch_1 = require("./statelessSwitch");
exports.deviceFeatures = {
    VibrationSensor: { experimental: false, hasBattery: true },
    MotionSensor: { experimental: false, hasBattery: true },
    LeakSensor: { experimental: false, hasBattery: true },
    Manipulator: { experimental: false, hasBattery: true },
    THSensor: { experimental: false, hasBattery: true },
    DoorSensor: { experimental: false, hasBattery: true },
    Siren: { experimental: true, hasBattery: true },
    Switch: { experimental: true, hasBattery: false },
    Outlet: { experimental: true, hasBattery: false },
    SmartRemoter: { experimental: false, hasBattery: true },
};
exports.initDeviceService = {
    VibrationSensor() { motionDevice_1.initMotionSensor.bind(this)(); },
    MotionSensor() { motionDevice_1.initMotionSensor.bind(this)(); },
    LeakSensor() { leakDevice_1.initLeakSensor.bind(this)(); },
    Manipulator() { valveDevice_1.initValveDevice.bind(this)(); },
    THSensor() { thermoHydroDevice_1.initThermoHydroDevice.bind(this)(); },
    DoorSensor() { contactDevice_1.initContactSensor.bind(this)(); },
    Siren() { switchDevice_1.initSwitchDevice.bind(this)('alert', { 'alarm': true }, { 'alarm': false }); },
    Switch() { switchDevice_1.initSwitchDevice.bind(this)('closed', 'close', 'open'); },
    Outlet() { outletDevice_1.initOutletDevice.bind(this)('closed', 'close', 'open'); },
    SmartRemoter() { statelessSwitch_1.initStatelessSwitch.bind(this)(4); },
};
exports.mqttHandler = {
    VibrationSensor(data) { motionDevice_1.mqttMotionSensor.bind(this)(data); },
    MotionSensor(data) { motionDevice_1.mqttMotionSensor.bind(this)(data); },
    LeakSensor(data) { leakDevice_1.mqttLeakSensor.bind(this)(data); },
    Manipulator(data) { valveDevice_1.mqttValveDevice.bind(this)(data); },
    THSensor(data) { thermoHydroDevice_1.mqttThermoHydroDevice.bind(this)(data); },
    DoorSensor(data) { contactDevice_1.mqttContactSensor.bind(this)(data); },
    Siren(data) { switchDevice_1.mqttSwitchDevice.bind(this)(data); },
    Switch(data) { switchDevice_1.mqttSwitchDevice.bind(this)(data); },
    Outlet(data) { outletDevice_1.mqttOutletDevice.bind(this)(data); },
    SmartRemoter(data) { statelessSwitch_1.mqttStatelessSwitch.bind(this)(data); },
};
//# sourceMappingURL=deviceHandlers.js.map